@@ -68,10 +68,10 @@ struct GRAdata
 typedef int (*clipfunc)(double *x0,double *y0,double *x1,double *y1,
                         void *local);
 typedef void (*transfunc)(double x0,double y0,int *x1,int *y1,void *local);
-typedef void (*diffunc)(double d,double c[],
+typedef void (*diffunc)(double d,const double c[],
                         double *dx,double *dy,double *ddx,double *ddy,
                         void *local);
-typedef void (*intpfunc)(double d,double c[],
+typedef void (*intpfunc)(double d,const double c[],
                         double x0,double y0,double *x,double *y,void *local);
 
 typedef int (*directfunc)(char code,int *cpar,char *cstr,void *local);
@@ -140,7 +140,7 @@ void GRAregion(int GC,int *width,int *height,int *zoom);
 int GRAend(int GC);
 void GRAview(int GC,int x1,int y1,int x2,int y2,int clip);
 void GRAwindow(int GC,double minx,double miny,double maxx,double maxy);
-void GRAlinestyle(int GC,int num,int *type,
+void GRAlinestyle(int GC,int num,const int *type,
                   int width,enum GRA_LINE_CAP cap,enum GRA_LINE_JOIN join,int miter);
 void GRAcolor(int GC, int fr, int fg, int fb, int fa);
 void GRAmoveto(int GC,int x,int y);
@@ -148,9 +148,9 @@ void GRAline(int GC,int x0,int y0,int x1,int y1);
 void GRAlineto(int GC,int x,int y);
 void GRAcircle(int GC,int x,int y,int rx,int ry,int cs,int ce,int fil);
 void GRArectangle(int GC,int x0,int y0,int x1,int y1,int fil);
-void GRAdrawpoly(int GC,int num,int *point,enum GRA_FILL_MODE fil);
-void GRAlines(int GC,int num,int *point);
-void GRArotate(int x0, int y0, int *pos, int *rpos, int n, double dx, double dy);
+void GRAdrawpoly(int GC,int num,const int *point,enum GRA_FILL_MODE fil);
+void GRAlines(int GC,int num,const int *point);
+void GRArotate(int x0, int y0, const int *pos, int *rpos, int n, double dx, double dy);
 void GRAmark_rotate(int GC,int type,int x0,int y0, double dx, double dy, int size,
 	     int fr,int fg,int fb, int fa, int br,int bg,int bb, int ba);
 void GRAmark(int GC,int type,int x0,int y0,int size,
@@ -166,7 +166,7 @@ void GRAtextextentraw(char *s,char *font, int style,
                  int size,int space,int *gx0,int *gy0,int *gx1,int *gy1);
 int GRAinput(int GC,char *s,int leftm,int topm,int rate_x,int rate_y);
 int GRAinputold(int GC,char *s,int leftm,int topm,int rate_x,int rate_y);
-void GRAcurvefirst(int GC,int num,int *dashlist,
+void GRAcurvefirst(int GC,int num,const int *dashlist,
       clipfunc clipf,transfunc transf,diffunc diff,intpfunc intpf,void *local,
              double x0,double y0);
 int GRAcurve(int GC,double c[],double x0,double y0);
