@@ -94,7 +94,7 @@ scrollbar_set_increment(GtkWidget *w, double step, double page)
   GtkAdjustment *adj;
   adj = gtk_scrollbar_get_adjustment(GTK_SCROLLBAR(w));
   gtk_adjustment_set_step_increment(adj, step);
-  gtk_adjustment_set_page_increment(adj, step);
+  gtk_adjustment_set_page_increment(adj, page);
 }
 
 void
@@ -228,7 +228,7 @@ set_widget_visibility_with_label(GtkWidget *w, gboolean state)
 }
 
 GtkWidget *
-add_widget_to_table_sub(GtkWidget *table, GtkWidget *w, const char *title, int expand, int col, int width, int col_max, int n)
+add_widget_to_table_sub(GtkWidget *table, GtkWidget *w, const char *title, int expand, int col, int width, int n)
 {
   GtkWidget *label;
 
@@ -260,7 +260,7 @@ add_widget_to_table_sub(GtkWidget *table, GtkWidget *w, const char *title, int e
 GtkWidget *
 add_widget_to_table(GtkWidget *table, GtkWidget *w, const char *title, int expand, int n)
 {
-  return add_widget_to_table_sub(table, w, title, expand, 0, (title) ? 1 : 2, 2, n);
+  return add_widget_to_table_sub(table, w, title, expand, 0, (title) ? 1 : 2, n);
 }
 
 GtkWidget *
@@ -350,6 +350,7 @@ entry_icon_file_select(GtkEntry *w, GtkEntryIconPosition icon_pos, gpointer user
   char *ext;
   const char *str;
   int chd;
+  (void) icon_pos;
 
   obj = (struct objlist *) user_data;
   if (obj == NULL)
@@ -385,7 +386,7 @@ create_file_entry(struct objlist *obj)
 }
 
 static void
-direction_icon_released(GtkSpinButton *entry, GtkEntryIconPosition pos, GdkEvent *event, gpointer user_data)
+direction_icon_released(GtkSpinButton *entry, GtkEntryIconPosition pos)
 {
   int angle, val;
 
@@ -423,15 +424,15 @@ direction_icon_released(GtkSpinButton *entry, GtkEntryIconPosition pos, GdkEvent
 }
 
 static void
-direction_down(GtkWidget *button, GtkSpinButton *user_data)
+direction_down(GtkSpinButton *button)
 {
-  direction_icon_released(user_data, GTK_ENTRY_ICON_PRIMARY, NULL, NULL);
+  direction_icon_released(button, GTK_ENTRY_ICON_PRIMARY);
 }
 
 static void
-direction_up(GtkWidget *button, GtkSpinButton *user_data)
+direction_up(GtkSpinButton *button)
 {
-  direction_icon_released(user_data, GTK_ENTRY_ICON_SECONDARY, NULL, NULL);
+  direction_icon_released(button, GTK_ENTRY_ICON_SECONDARY);
 }
 
 GtkWidget *
@@ -444,10 +445,10 @@ create_direction_entry(GtkWidget *table, const char *title, int row)
   gtk_editable_set_max_width_chars(GTK_EDITABLE(w), NUM_ENTRY_WIDTH);
 
   ubtn = button_new_with_icon("go-up-symbolic", FALSE);
-  g_signal_connect(ubtn, "clicked", G_CALLBACK(direction_up), w);
+  g_signal_connect_swapped(ubtn, "clicked", G_CALLBACK(direction_up), w);
 
   dbtn = button_new_with_icon("go-down-symbolic", FALSE);
-  g_signal_connect(dbtn, "clicked", G_CALLBACK(direction_down), w);
+  g_signal_connect_swapped(dbtn, "clicked", G_CALLBACK(direction_down), w);
 
   box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_append(GTK_BOX(box), w);
@@ -602,6 +603,8 @@ spin_change_value_cb(GtkSpinButton *spinbutton, GtkScrollType arg1, gpointer use
   const char *str;
   double oval, val;
   int ecode;
+  (void) arg1;
+  (void) user_data;
 
   str = gtk_editable_get_text(GTK_EDITABLE(spinbutton));
   if (str == NULL)
@@ -773,6 +776,7 @@ show_color_sel(GtkWidget *w, gpointer user_data)
 {
   GdkRGBA col;
   char buf[64];
+  (void) user_data;
 
   gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(w), &col);
   snprintf(buf, sizeof(buf),
@@ -819,10 +823,8 @@ set_default_palette(GtkWidget *cc)
 #define CUSTOM_PALETTE_KEY "custom_palette"
 
 static void
-show_color_dialog(GtkGestureClick *gesture, gint n_press, gdouble x, gdouble y, gpointer user_data)
+show_color_dialog(GtkColorChooser *btn)
 {
-  GtkColorChooser *btn;
-  btn = GTK_COLOR_CHOOSER(user_data);
   gtk_color_chooser_add_palette(GTK_COLOR_CHOOSER(btn), GTK_ORIENTATION_HORIZONTAL, 0, 0, NULL);
   if (Menulocal.use_custom_palette) {
     set_custom_palette(GTK_WIDGET(btn));
@@ -832,7 +834,7 @@ show_color_dialog(GtkGestureClick *gesture, gint n_press, gdouble x, gdouble y,
 }
 
 GtkWidget *
-create_color_button(GtkWidget *win)
+create_color_button(void)
 {
   GtkGesture *gesture;
   GtkWidget *w;
@@ -840,12 +842,12 @@ create_color_button(GtkWidget *win)
   w = gtk_color_button_new();
   gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(w), FALSE);
   g_object_set_data(G_OBJECT(w), CUSTOM_PALETTE_KEY, GINT_TO_POINTER(0));
-  g_signal_connect(w, "color-set", G_CALLBACK(show_color_sel), win);
+  g_signal_connect(w, "color-set", G_CALLBACK(show_color_sel), NULL);
   gesture = gtk_gesture_click_new();
   gtk_widget_add_controller(w, GTK_EVENT_CONTROLLER(gesture));
 
   gtk_gesture_single_set_button(GTK_GESTURE_SINGLE(gesture), 0);
-  g_signal_connect(gesture, "pressed", G_CALLBACK(show_color_dialog), w);
+  g_signal_connect_swapped(gesture, "pressed", G_CALLBACK(show_color_dialog), w);
 
   return w;
 }
