@@ -88,10 +88,9 @@ struct gtklocal
 };
 
 static void gtkMakeRuler(cairo_t *cr, struct gtklocal *gtklocal);
-static int gtkclose(GtkWidget *widget, gpointer user_data);
+static int gtkclose(const GtkWidget *widget);
 static void gtkchangedpi(struct gtklocal *gtklocal);
-static gboolean gtkevpaint(GtkWidget * w, cairo_t * e,
-			   gpointer user_data);
+static gboolean gtkevpaint(struct gtklocal *gtklocal, cairo_t * e);
 static int gtkinit(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc,
 		   char **argv);
 static int gtkdone(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc,
@@ -106,12 +105,8 @@ static int gtk_output(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int arg
 static void resized(GtkWidget *widget, int w, int h, gpointer user_data);
 
 static gboolean
-gtkevpaint(GtkWidget *w, cairo_t *cr, gpointer user_data)
+gtkevpaint(struct gtklocal *gtklocal, cairo_t *cr)
 {
-  struct gtklocal *gtklocal;
-
-  gtklocal = (struct gtklocal *) user_data;
-
   if (gtklocal->surface == NULL) {
     return FALSE;
   }
@@ -129,10 +124,8 @@ gtkevpaint(GtkWidget *w, cairo_t *cr, gpointer user_data)
 }
 
 static void
-destroyed(GtkWidget *win, gpointer user_data)
+destroyed(struct gtklocal *local)
 {
-  struct gtklocal *local;
-  local = (struct gtklocal *) user_data;
   if (local->quit_main_loop) {
     g_idle_add_once((GSourceOnceFunc) g_main_loop_quit, main_loop());
   }
@@ -140,7 +133,7 @@ destroyed(GtkWidget *win, gpointer user_data)
 }
 
 static int
-gtkclose(GtkWidget *widget, gpointer user_data)
+gtkclose(const GtkWidget *widget)
 {
   struct gtklocal *local;
   int i, id;
@@ -161,7 +154,7 @@ gtkclose(GtkWidget *widget, gpointer user_data)
 }
 
 static void
-size_allocate(GtkWidget *widget, GdkRectangle *allocation, gpointer user_data)
+size_allocate(GtkWidget *widget, const GdkRectangle *allocation, gpointer user_data)
 {
   double w, h;
   w = allocation->width;
@@ -175,6 +168,7 @@ resized(GtkWidget *widget, int w, int h, gpointer user_data)
   struct gtklocal *local;
   double rh, rw, ratio;
   int pw, ph, dpi;
+  (void) widget;
 
   local = (struct gtklocal *) user_data;
   if (local == NULL) {
@@ -211,7 +205,10 @@ resized(GtkWidget *widget, int w, int h, gpointer user_data)
 static void
 draw_function(GtkDrawingArea* drawing_area, cairo_t* cr, int width, int height, gpointer user_data)
 {
-  gtkevpaint(GTK_WIDGET(drawing_area), cr, user_data);
+  (void) drawing_area;
+  (void) width;
+  (void) height;
+  gtkevpaint(user_data, cr);
 }
 
 static int
@@ -312,8 +309,8 @@ gtkinit(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv
 #endif
   }
   gtk_window_set_default_size(GTK_WINDOW(gtklocal->mainwin), width, height);
-  g_signal_connect(gtklocal->mainwin, "close_request", G_CALLBACK(gtkclose), gtklocal);
-  g_signal_connect(gtklocal->mainwin, "destroy", G_CALLBACK(destroyed), gtklocal);
+  g_signal_connect(gtklocal->mainwin, "close_request", G_CALLBACK(gtkclose), NULL);
+  g_signal_connect_swapped(gtklocal->mainwin, "destroy", G_CALLBACK(destroyed), gtklocal);
 
   gtk_window_set_title((GtkWindow *) gtklocal->mainwin, gtklocal->title);
 
@@ -498,7 +495,7 @@ gtkflush(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **arg
 }
 
 static double
-get_color(const struct gtklocal *gtklocal, int argc, char **argv)
+get_color(int argc, char **argv)
 {
   int c;
 
@@ -516,6 +513,7 @@ gtkbg(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
 {
   struct gtklocal *gtklocal;
   const char *field;
+  (void) rval;
 
   if (_getobj(obj, "_gtklocal", inst, &gtklocal))
     return 1;
@@ -523,13 +521,13 @@ gtkbg(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
   field = argv[1];
   switch(field[1]) {
   case 'R':
-    gtklocal->bg_r = get_color(gtklocal, argc, argv);
+    gtklocal->bg_r = get_color(argc, argv);
     break;
   case 'G':
-    gtklocal->bg_g = get_color(gtklocal, argc, argv);
+    gtklocal->bg_g = get_color(argc, argv);
     break;
   case 'B':
-    gtklocal->bg_b = get_color(gtklocal, argc, argv);
+    gtklocal->bg_b = get_color(argc, argv);
     break;
   }
   return 0;
@@ -539,6 +537,9 @@ static int
 gtkredraw(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
 {
   struct gtklocal *gtklocal;
+  (void) rval;
+  (void) argc;
+  (void) argv;
 
   if (_getobj(obj, "_gtklocal", inst, &gtklocal))
     return 1;
@@ -654,6 +655,7 @@ gtk_set_dpi(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **
 {
   int dpi, fit;
   struct gtklocal *local;
+  (void) rval;
 
   dpi = abs(*(int *) argv[2]);
 
@@ -683,6 +685,7 @@ gtk_set_fit(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **
 {
   int fit;
   struct gtklocal *local;
+  (void) rval;
 
   _getobj(obj, "_gtklocal", inst, &local);
 
@@ -691,8 +694,9 @@ gtk_set_fit(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **
   local->fit = fit;
 
   if (fit && local->mainwin) {
-    GtkAllocation allocation;
-    gtk_widget_get_allocation(local->mainwin, &allocation);
+    GdkRectangle allocation;
+    allocation.width = gtk_widget_get_width (GTK_WIDGET (local->mainwin));
+    allocation.height = gtk_widget_get_height (GTK_WIDGET (local->mainwin));
     size_allocate(local->mainwin, &allocation, local);
   }
 
@@ -703,6 +707,7 @@ static int
 gtk_set_frame(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char **argv)
 {
   struct gtklocal *local;
+  (void) rval;
 
   _getobj(obj, "_gtklocal", inst, &local);
 
@@ -716,6 +721,7 @@ gtk_set_size(struct objlist *obj, N_VALUE *inst, N_VALUE *rval, int argc, char *
 {
   int width, height, size;
   struct gtklocal *local;
+  (void) rval;
 
   _getobj(obj, "_gtklocal", inst, &local);
 
