@@ -271,13 +271,13 @@ gauge_syle_setup(struct GridDialog *d, GtkWidget *table, int n, int j, int insta
 
   snprintf(buf, sizeof(buf), _("_Style %d:"), n + 1);
   w = combo_box_entry_create();
-  add_widget_to_table_sub(table, w, buf, TRUE, 0, 1, 4, j);
+  add_widget_to_table_sub(table, w, buf, TRUE, 0, 1, j);
   d->style[n] = w;
 
   if (instance) {
     snprintf(buf, sizeof(buf), _("_Width %d:"), n + 1);
     w = create_spin_entry_type(SPIN_BUTTON_TYPE_WIDTH, TRUE, TRUE);
-    add_widget_to_table_sub(table, w, buf, FALSE, 2, 1, 4, j);
+    add_widget_to_table_sub(table, w, buf, FALSE, 2, 1, j);
   } else {
     w = NULL;
   }
@@ -339,7 +339,7 @@ GridDialogSetupCommon(GtkWidget *wi, void *data, int makewidget, int instance)
     table = gtk_grid_new();
 
     j = 0;
-    w = create_color_button(wi);
+    w = create_color_button();
     add_widget_to_table(table, w, _("_Color:"), FALSE, j++);
     d->color = w;
 
@@ -352,7 +352,7 @@ GridDialogSetupCommon(GtkWidget *wi, void *data, int makewidget, int instance)
     g_signal_connect(w, "toggled", G_CALLBACK(bg_button_toggled), d);
     d->background = w;
 
-    w = create_color_button(wi);
+    w = create_color_button();
     add_widget_to_table(table, w, _("_Background Color:"), FALSE, j++);
     d->bcolor = w;
 
@@ -396,6 +396,7 @@ GridDialogClose(GtkWidget *w, void *data)
   struct GridDialog *d;
   int ret;
   int i;
+  (void) w;
 
   d = (struct GridDialog *) data;
 
@@ -533,7 +534,7 @@ set_axis_id(GtkWidget *w, int id)
 }
 
 static void
-SectionDialogSetupItem(GtkWidget *w, struct SectionDialog *d)
+SectionDialogSetupItem(struct SectionDialog *d)
 {
   spin_entry_set_val(d->x, d->X);
   spin_entry_set_val(d->y, d->Y);
@@ -633,7 +634,7 @@ section_dialog_grid_response(struct response_callback *cb)
     menu_delete_undo(undo);
     set_graph_modified();
   }
-  SectionDialogSetupItem(d->widget, d);
+  SectionDialogSetupItem(d);
   g_clear_pointer(&cb->data, g_free);
 }
 
@@ -676,6 +677,7 @@ static void
 SectionDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
   struct SectionDialog *d;
+  (void) wi;
 
   d = (struct SectionDialog *) data;
 
@@ -781,7 +783,7 @@ SectionDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_append(GTK_BOX(d->vbox), hbox);
   }
 
-  SectionDialogSetupItem(wi, d);
+  SectionDialogSetupItem(d);
 }
 
 static void
@@ -791,6 +793,7 @@ SectionDialogClose(GtkWidget *w, void *data)
   int ret;
   int type;
   struct narray group;
+  (void) w;
 
   d = (struct SectionDialog *) data;
   if (d->ret != IDOK)
@@ -856,7 +859,7 @@ SectionDialog(struct SectionDialog *data,
 }
 
 static void
-CrossDialogSetupItem(GtkWidget *w, struct CrossDialog *d)
+CrossDialogSetupItem(struct CrossDialog *d)
 {
   spin_entry_set_val(d->x, d->X);
   spin_entry_set_val(d->y, d->Y);
@@ -890,6 +893,7 @@ static void
 CrossDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
   struct CrossDialog *d;
+  (void) wi;
 
   d = (struct CrossDialog *) data;
   if (makewidget) {
@@ -952,7 +956,7 @@ CrossDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_append(GTK_BOX(hbox), vbox);
     gtk_box_append(GTK_BOX(d->vbox), hbox);
   }
-  CrossDialogSetupItem(wi, d);
+  CrossDialogSetupItem(d);
 }
 
 static void
@@ -962,6 +966,7 @@ CrossDialogClose(GtkWidget *w, void *data)
   int ret;
   int type;
   struct narray group;
+  (void) w;
 
   d = (struct CrossDialog *) data;
   if (d->ret != IDOK)
@@ -1021,7 +1026,7 @@ CrossDialog(struct CrossDialog *data,
 }
 
 static void
-ZoomDialogSetupItem(GtkWidget *w, struct ZoomDialog *d)
+ZoomDialogSetupItem(struct ZoomDialog *d)
 {
   spin_entry_set_val(d->zoom_entry, d->zoom);
 }
@@ -1030,6 +1035,7 @@ static void
 ZoomDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
   struct ZoomDialog *d;
+  (void) wi;
 
   d = (struct ZoomDialog *) data;
   if (makewidget) {
@@ -1040,13 +1046,14 @@ ZoomDialogSetup(GtkWidget *wi, void *data, int makewidget)
     d->zoom_entry = w;
     gtk_box_append(GTK_BOX(d->vbox), vbox);
   }
-  ZoomDialogSetupItem(wi, d);
+  ZoomDialogSetupItem(d);
 }
 
 static void
 ZoomDialogClose(GtkWidget *w, void *data)
 {
   struct ZoomDialog *d;
+  (void) w;
 
   d = (struct ZoomDialog *) data;
   if (d->ret != IDOK)
@@ -1256,6 +1263,7 @@ file_button_show(GtkWidget *widget, gpointer user_data)
 {
   static struct objlist *file = NULL;
   int n;
+  (void) user_data;
 
   if (file == NULL) {
     file = chkobject("data");
@@ -1434,7 +1442,7 @@ baseline_tab_copy_clicked(struct AxisDialog *d)
 }
 
 static GtkWidget *
-baseline_tab_create(GtkWidget *wi, struct AxisDialog *dd)
+baseline_tab_create(struct AxisDialog *dd)
 {
   GtkWidget *w, *hbox, *vbox, *frame, *table;
   struct AxisBase *d;
@@ -1460,7 +1468,7 @@ baseline_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   add_widget_to_table(table, w, _("_Line Width:"), FALSE, i++);
   d->width = w;
 
-  w = create_color_button(wi);
+  w = create_color_button();
   add_widget_to_table(table, w, _("_Color:"), FALSE, i++);
   d->color = w;
 
@@ -1610,7 +1618,7 @@ gauge_tab_copy_clicked(struct AxisDialog *d)
 }
 
 static GtkWidget *
-gauge_tab_create(GtkWidget *wi, struct AxisDialog *dd)
+gauge_tab_create(struct AxisDialog *dd)
 {
   GtkWidget *parent_box, *w, *vbox, *frame, *table;
   struct AxisGauge *d;
@@ -1647,11 +1655,11 @@ gauge_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   j = 0;
   w = combo_box_entry_create();
-  add_widget_to_table_sub(table, w, _("_Style:"), TRUE, 0, 3, 4, j++);
+  add_widget_to_table_sub(table, w, _("_Style:"), TRUE, 0, 3, j++);
   d->style = w;
 
-  w = create_color_button(wi);
-  add_widget_to_table_sub(table, w, _("_Color:"), FALSE, 0, 1, 4, j++);
+  w = create_color_button();
+  add_widget_to_table_sub(table, w, _("_Color:"), FALSE, 0, 1, j++);
   d->color = w;
 
   w = create_spin_entry_type(SPIN_BUTTON_TYPE_ALPHA, FALSE, TRUE);
@@ -1661,12 +1669,12 @@ gauge_tab_create(GtkWidget *wi, struct AxisDialog *dd)
   for (i = 0; i < GAUGE_STYLE_NUM; i++) {
     snprintf(buf, sizeof(buf), _("_Width %d:"), i + 1);
     w = create_spin_entry_type(SPIN_BUTTON_TYPE_WIDTH, TRUE, TRUE);
-    add_widget_to_table_sub(table, w, buf, TRUE, 0, 1, 4, j);
+    add_widget_to_table_sub(table, w, buf, TRUE, 0, 1, j);
     d->width[i] = w;
 
     snprintf(buf, sizeof(buf), _("_Length %d:"), i + 1);
     w = create_spin_entry_type(SPIN_BUTTON_TYPE_LENGTH, TRUE, TRUE);
-    add_widget_to_table_sub(table, w, buf, TRUE, 2, 1, 4, j++);
+    add_widget_to_table_sub(table, w, buf, TRUE, 2, 1, j++);
     d->length[i] = w;
   }
 
@@ -1867,6 +1875,7 @@ num_direction_changed(GtkWidget *w, GParamSpec *pspec, gpointer client_data)
 {
   int dir, state;
   struct AxisDialog *d;
+  (void) pspec;
 
   d = (struct AxisDialog *) client_data;
 
@@ -1879,7 +1888,7 @@ num_direction_changed(GtkWidget *w, GParamSpec *pspec, gpointer client_data)
 }
 
 static GtkWidget *
-numbering_tab_create(GtkWidget *wi, struct AxisDialog *dd)
+numbering_tab_create(struct AxisDialog *dd)
 {
   GtkWidget *w, *hbox, *vbox, *frame, *table;
   struct AxisNumbering *d;
@@ -2084,7 +2093,7 @@ font_tab_copy_clicked(struct AxisDialog *d)
 }
 
 static GtkWidget *
-font_tab_create(GtkWidget *wi, struct AxisDialog *dd)
+font_tab_create(struct AxisDialog *dd)
 {
   GtkWidget *w, *vbox, *table, *frame, *btn_box;
   struct AxisFont *d;
@@ -2122,7 +2131,7 @@ font_tab_create(GtkWidget *wi, struct AxisDialog *dd)
 
   add_widget_to_table(table, btn_box, "", FALSE, i++);
 
-  w = create_color_button(wi);
+  w = create_color_button();
   add_widget_to_table(table, w, _("_Color:"), FALSE, i++);
   d->color = w;
 
@@ -2208,7 +2217,7 @@ position_tab_copy_clicked(struct AxisDialog *d)
 }
 
 static GtkWidget *
-position_tab_create(GtkWidget *wi, struct AxisDialog *dd)
+position_tab_create(struct AxisDialog *dd)
 {
   GtkWidget *w, *vbox, *frame, *table;
   struct AxisPos *d;
@@ -2278,23 +2287,23 @@ AxisDialogSetup(GtkWidget *wi, void *data, int makewidget)
     label = gtk_label_new_with_mnemonic(_("_Scale"));
     gtk_notebook_append_page(GTK_NOTEBOOK(notebook), w, label);
 
-    w = baseline_tab_create(wi, d);
+    w = baseline_tab_create(d);
     label = gtk_label_new_with_mnemonic(_("_Baseline"));
     d->base.tab_id = gtk_notebook_append_page(GTK_NOTEBOOK(notebook), w, label);
 
-    w = gauge_tab_create(wi, d);
+    w = gauge_tab_create(d);
     label = gtk_label_new_with_mnemonic(_("_Gauge"));
     d->gauge.tab_id = gtk_notebook_append_page(GTK_NOTEBOOK(notebook), w, label);
 
-    w = numbering_tab_create(wi, d);
+    w = numbering_tab_create(d);
     label = gtk_label_new_with_mnemonic(_("_Numbering"));
     d->numbering.tab_id = gtk_notebook_append_page(GTK_NOTEBOOK(notebook), w, label);
 
-    w = font_tab_create(wi, d);
+    w = font_tab_create(d);
     label = gtk_label_new_with_mnemonic(_("_Font"));
     d->font.tab_id = gtk_notebook_append_page(GTK_NOTEBOOK(notebook), w, label);
 
-    w = position_tab_create(wi, d);
+    w = position_tab_create(d);
     label = gtk_label_new_with_mnemonic(_("_Position"));
     d->position.tab_id = gtk_notebook_append_page(GTK_NOTEBOOK(notebook), w, label);
 
@@ -2352,6 +2361,7 @@ AxisDialogClose(GtkWidget *w, void *data)
 {
   struct AxisDialog *d;
   int ret;
+  (void) w;
 
   d = (struct AxisDialog *) data;
 
@@ -2402,6 +2412,7 @@ void
 AxisDialog(struct obj_list_data *data, int id, int user_data)
 {
   struct AxisDialog *d;
+  (void) user_data;
 
   d = (struct AxisDialog *) data->dialog;
 
@@ -2416,6 +2427,9 @@ CmAxisAddFrame
 (GSimpleAction *action, GVariant *parameter, gpointer client_data)
 {
   enum TOOLBOX_MODE mode;
+  (void) action;
+  (void) parameter;
+  (void) client_data;
   mode = get_toolbox_mode();
   CmAxisNewFrame(mode == TOOLBOX_MODE_SETTING_PANEL, NULL);
 }
@@ -2425,6 +2439,9 @@ CmAxisAddSection
 (GSimpleAction *action, GVariant *parameter, gpointer client_data)
 {
   enum TOOLBOX_MODE mode;
+  (void) action;
+  (void) parameter;
+  (void) client_data;
   mode = get_toolbox_mode();
   CmAxisNewSection(mode == TOOLBOX_MODE_SETTING_PANEL, NULL);
 }
@@ -2434,6 +2451,9 @@ CmAxisAddCross
 (GSimpleAction *action, GVariant *parameter, gpointer client_data)
 {
   enum TOOLBOX_MODE mode;
+  (void) action;
+  (void) parameter;
+  (void) client_data;
   mode = get_toolbox_mode();
   CmAxisNewCross(mode == TOOLBOX_MODE_SETTING_PANEL, NULL);
 }
@@ -2664,6 +2684,9 @@ CmAxisAddSingle
 {
   struct objlist *obj;
   int id, undo;
+  (void) action;
+  (void) parameter;
+  (void) client_data;
 
   if (Menulock || Globallock)
     return;
@@ -2869,6 +2892,8 @@ axiswin_scale_clear(GSimpleAction *action, GVariant *parameter, gpointer user_da
   struct obj_list_data *d;
   struct objlist *obj;
   int sel, num;
+  (void) action;
+  (void) parameter;
 
   if (Menulock || Globallock)
     return;
@@ -3125,6 +3150,7 @@ AxisWinUpdate(struct obj_list_data *d, int clear, int draw)
 static void
 AxisDelCB(struct obj_list_data *data, int id)
 {
+  (void) data;
   AxisDel(id);
 }
 
@@ -3282,6 +3308,7 @@ popup_show_cb(GtkWidget *widget, gpointer user_data)
 {
   int sel, num, last_id, i;
   struct obj_list_data *d;
+  (void) widget;
 
   d = (struct obj_list_data *) user_data;
 
@@ -3341,6 +3368,8 @@ static void
 axis_delete_popup_func(GSimpleAction *action, GVariant *parameter, gpointer client_data)
 {
   struct obj_list_data *d;
+  (void) action;
+  (void) parameter;
 
   d = (struct obj_list_data *) client_data;
   axiswin_delete_axis(d);
@@ -3351,6 +3380,8 @@ AxisWinAxisTop(GSimpleAction *action, GVariant *parameter, gpointer client_data)
 {
   int sel, num;
   struct obj_list_data *d;
+  (void) action;
+  (void) parameter;
 
   d = (struct obj_list_data *) client_data;
 
@@ -3375,6 +3406,8 @@ AxisWinAxisLast(GSimpleAction *action, GVariant *parameter, gpointer client_data
 {
   int sel, num;
   struct obj_list_data *d;
+  (void) action;
+  (void) parameter;
 
   d = (struct obj_list_data *) client_data;
 
@@ -3399,6 +3432,8 @@ AxisWinAxisUp(GSimpleAction *action, GVariant *parameter, gpointer client_data)
 {
   int sel, num;
   struct obj_list_data *d;
+  (void) action;
+  (void) parameter;
 
   d = (struct obj_list_data *) client_data;
 
@@ -3423,6 +3458,8 @@ AxisWinAxisDown(GSimpleAction *action, GVariant *parameter, gpointer client_data
 {
   int sel, num;
   struct obj_list_data *d;
+  (void) action;
+  (void) parameter;
 
   d = (struct obj_list_data *) client_data;
 
