@@ -36,22 +36,29 @@ void FitCopy(struct objlist *obj, int did, int sid);
 void FitDel(struct objlist *obj, int id);
 void ArrayDel(struct objlist *obj, int id);
 void FitClear(void);
-int LoadNgpFile(char *File, int console, char *option);
-int SaveDrawrable(char *name, int storedata, int storemerge, int save_decimalsign);
-int GraphSave(int overwrite);
+
+typedef void (* obj_response_cb) (int response, struct objlist *obj, int id, int modified);
+
+void LoadNgpFile(const char *File, int console, const char *option, const char *cwd);
+void CheckSave(response_cb cb, gpointer user_data);
+void CheckIniFile(obj_response_cb cb, struct objlist *obj, int id, int modified);
+int SaveDrawrable(const char *name, int storedata, int storemerge, int save_decimalsign);
+int GraphSave(int overwrite, response_cb cb, gpointer user_data);
 void DeleteDrawable(void);
 void FileAutoScale(void);
-int CheckSave(void);
 void AddDataFileList(const char *file);
 void SetFileName(char *name);
-int CheckIniFile(void);
 int allocate_console(void);
 void free_console(int allocnow);
 char *FileCB(struct objlist *obj, int id);
 char *PlotFileCB(struct objlist *obj, int id);
 char *MergeFileCB(struct objlist *obj, int id);
-int SetFileHidden(void);
-void ProgressDialogCreate(char *title);
-void ProgressDialogSetTitle(char *title);
-void ProgressDialogFinalize(void);
+
+typedef void (* progress_func) (gpointer user_data);
+
+void SetFileHidden(response_cb cb, gpointer user_data);
+void ProgressDialogSetTitle(const char *title);
+void ProgressDialogCreate(const char *title, progress_func update, progress_func finalize, gpointer data);
+void ProgressDialog_append_text(const char *text);
+int ProgressDialogIsActive(void);
 void ErrorMessage(void);
