@@ -276,6 +276,8 @@ dialog_add_move_button (struct DialogType *data)
 static gboolean
 dialog_escape (GtkWidget* widget, GVariant* args, gpointer user_data)
 {
+  (void) args;
+  (void) user_data;
   gtk_window_close (GTK_WINDOW (widget));
   return TRUE;
 }
@@ -320,6 +322,7 @@ DialogExecute(GtkWidget *parent, void *dialog)
 
     data->parent = parent;
     data->widget = dlg;
+    gtk_window_set_title (GTK_WINDOW (dlg), _(data->resource));
     data->vbox = GTK_BOX(gtk_box_new (GTK_ORIENTATION_VERTICAL, 0));
     headerbar = gtk_header_bar_new();
     gtk_header_bar_set_decoration_layout (GTK_HEADER_BAR (headerbar), "");
