@@ -1093,6 +1093,9 @@ term_signal_handler(int sig)
 static gboolean
 CloseCallback(GtkWidget *w, GdkEvent *event, gpointer user_data)
 {
+  (void) w;
+  (void) event;
+  (void) user_data;
   CmGraphQuit();
 
   return TRUE;
@@ -1581,26 +1584,6 @@ create_object_tabs(void)
   }
 }
 
-static void
-edit_menu_shown(GtkWidget *w, gpointer user_data)
-{
-  const struct Viewer *d;
-
-  d = (struct Viewer *) user_data;
-
-  set_focus_sensitivity(d);
-}
-
-static void
-clipboard_changed(GdkClipboard* self,  gpointer user_data)
-{
-  const struct Viewer *d;
-
-  d = (struct Viewer *) user_data;
-
-  set_focus_sensitivity(d);
-}
-
 #define USE_APP_HEADER_BAR 0
 static void
 setup_toolbar(GtkWidget *window)
@@ -1644,7 +1627,7 @@ setupwindow(GtkApplication *app)
   gtk_box_append(GTK_BOX(hbox), PToolbar);
 
   if (NgraphApp.Viewer.popup) {
-    g_signal_connect(NgraphApp.Viewer.popup, "show", G_CALLBACK(edit_menu_shown), &NgraphApp.Viewer);
+    g_signal_connect_swapped(NgraphApp.Viewer.popup, "show", G_CALLBACK(set_focus_sensitivity), &NgraphApp.Viewer);
   }
 
   NgraphApp.Viewer.HScroll = gtk_scrollbar_new(GTK_ORIENTATION_HORIZONTAL, NULL);
@@ -1672,6 +1655,7 @@ setupwindow(GtkApplication *app)
   gtk_grid_attach(GTK_GRID(table), NgraphApp.Viewer.Win,     1, 1, 1, 1);
 
   vpane2 = gtk_paned_new(GTK_ORIENTATION_VERTICAL);
+  gtk_paned_set_wide_handle (GTK_PANED (vpane2), TRUE);
   NgraphApp.Viewer.side_pane2 = vpane2;
 
   w = gtk_notebook_new();
@@ -1692,6 +1676,7 @@ setupwindow(GtkApplication *app)
   NgraphApp.Viewer.side_pane3 = hpane2;
 
   vpane1 = gtk_paned_new(GTK_ORIENTATION_VERTICAL);
+  gtk_paned_set_wide_handle (GTK_PANED (vpane1), TRUE);
   gtk_paned_set_start_child(GTK_PANED(vpane1), vpane2);
   gtk_paned_set_end_child(GTK_PANED(vpane1), hpane2);
   NgraphApp.Viewer.side_pane1 = vpane1;
@@ -2472,7 +2457,7 @@ create_toplevel_window(void)
     NgraphApp.Viewer.popup = popup;
   }
   clip = gtk_widget_get_clipboard(TopLevel);
-  g_signal_connect(clip, "changed", G_CALLBACK(clipboard_changed), &NgraphApp.Viewer);
+  g_signal_connect_swapped(clip, "changed", G_CALLBACK(set_focus_sensitivity), &NgraphApp.Viewer);
 
   gtk_window_set_title(GTK_WINDOW(TopLevel), AppName);
   gtk_window_set_default_size(GTK_WINDOW(TopLevel), width, height);
@@ -2728,8 +2713,6 @@ UpdateAll2(char **objs, int redraw)
     MergeWinUpdate(NgraphApp.MergeWin.data.data, TRUE, redraw);
   }
   LegendWinUpdate(objs, TRUE, redraw);
-  InfoWinUpdate(TRUE);
-  CoordWinUpdate(TRUE);
   ParameterWinUpdate(NgraphApp.ParameterWin.data.data, FALSE, redraw);
   presetting_set_parameters(&NgraphApp.Viewer);
 }
