@@ -67,6 +67,7 @@ DefaultDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
   struct DefaultDialog *d;
   GtkWidget *w;
+  (void) wi;
 
   d = (struct DefaultDialog *) data;
 
@@ -100,6 +101,8 @@ DefaultDialogSetup(GtkWidget *wi, void *data, int makewidget)
 static void
 save_config_response(int ret, struct objlist *obj, int id, int type)
 {
+  (void) obj;
+  (void) id;
   if (! ret) {
     return;
   }
@@ -135,6 +138,7 @@ DefaultDialogClose(GtkWidget *win, void *data)
     {NULL, SAVE_CONFIG_TYPE_EXTERNAL_VIEWER},
     {NULL, SAVE_CONFIG_TYPE_FONTS},
   };
+  (void) win;
 
   d = (struct DefaultDialog *) data;
 
@@ -175,6 +179,7 @@ active_script_changed(GtkWidget *widget, GParamSpec *spec,  gpointer user_data)
   struct SetScriptDialog *d;
   struct script *addin;
   int i, n;
+  (void) spec;
 
   d = (struct SetScriptDialog *) user_data;
 
@@ -227,7 +232,7 @@ remove_char(char *str, int c)
 }
 
 static void
-SetScriptDialogSetupItem(GtkWidget *w, struct SetScriptDialog *d)
+SetScriptDialogSetupItem(struct SetScriptDialog *d)
 {
   struct script *addin;
 
@@ -274,6 +279,8 @@ SetScriptDialogBrowse_response(char *file, gpointer user_data)
 static void
 SetScriptDialogBrowse(GtkEntry *w, GtkEntryIconPosition icon_pos, gpointer user_data)
 {
+  (void) icon_pos;
+  (void) user_data;
   nGetOpenFileName(TopLevel, _("Add-in Script"), "nsc", NULL, NULL, FALSE,
                    SetScriptDialogBrowse_response, w);
 }
@@ -282,6 +289,7 @@ static void
 SetScriptDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
   struct SetScriptDialog *d;
+  (void) wi;
 
   d = (struct SetScriptDialog *) data;
   if (makewidget) {
@@ -314,7 +322,7 @@ SetScriptDialogSetup(GtkWidget *wi, void *data, int makewidget)
 
     gtk_box_append(GTK_BOX(d->vbox), table);
   }
-  SetScriptDialogSetupItem(wi, d);
+  SetScriptDialogSetupItem(d);
 }
 
 static int
@@ -366,6 +374,7 @@ SetScriptDialogClose(GtkWidget *w, void *data)
 {
   int ret;
   struct SetScriptDialog *d;
+  (void) w;
 
   d = (struct SetScriptDialog *) data;
 
@@ -477,6 +486,7 @@ static void
 PrefScriptDialogClose(GtkWidget *w, void *data)
 {
   const struct PrefScriptDialog *d;
+  (void) w;
 
   d = (struct PrefScriptDialog *) data;
 
@@ -498,7 +508,20 @@ PrefScriptDialog(struct PrefScriptDialog *data)
 }
 
 static void
-FontSettingDialogSetupItem(GtkWidget *w, struct FontSettingDialog *d)
+font_button_set_font (GtkWidget *btn, const char *font)
+{
+  PangoFontDescription *desc;
+
+  desc = pango_font_description_from_string (font);
+  if (desc == NULL) {
+    return;
+  }
+  gtk_font_dialog_button_set_font_desc (GTK_FONT_DIALOG_BUTTON (btn), desc);
+  pango_font_description_free (desc);
+}
+
+static void
+FontSettingDialogSetupItem(struct FontSettingDialog *d)
 {
   GtkSelectionModel *model;
   editable_set_init_text(d->alias, CHK_STR(d->alias_str));
@@ -508,7 +531,7 @@ FontSettingDialogSetupItem(GtkWidget *w, struct FontSettingDialog *d)
     char *tmp;
 
     tmp = g_strdup_printf("%s, 16", d->font_str);
-    gtk_font_chooser_set_font(GTK_FONT_CHOOSER(d->font_b), tmp);
+    font_button_set_font(d->font_b, tmp);
     g_free(tmp);
   }
 
@@ -538,6 +561,8 @@ AlternativeFontListSelCb(GtkSelectionModel *sel, guint position, guint n_items,
 {
   int a, n;
   struct FontSettingDialog *d;
+  (void) position;
+  (void) n_items;
 
   d = (struct FontSettingDialog *) user_data;
 
@@ -551,75 +576,45 @@ AlternativeFontListSelCb(GtkSelectionModel *sel, guint position, guint n_items,
   return FALSE;
 }
 
-static gchar *
-get_font_family(const gchar *font_name)
-{
-  gchar *ptr;
-  const gchar *family;
-  PangoFontDescription *pdesc;
-
-  pdesc = pango_font_description_from_string(font_name);
-  family = pango_font_description_get_family(pdesc);
-  if (family == NULL) {
-    return NULL;
-  }
-
-  ptr = g_strdup(family);
-
-  pango_font_description_free(pdesc);
-
-  return ptr;
-}
-
 static void
-FontSettingDialogAddAlternative_response(GtkWidget *dialog, gint response, gpointer client_data)
+FontSettingDialogAddAlternative_response(GObject *source_object, GAsyncResult *res, gpointer client_data)
 {
-  struct FontSettingDialog *d;
   PangoFontFamily *family;
-
-  if (response != GTK_RESPONSE_OK) {
-    gtk_window_destroy(GTK_WINDOW(dialog));
-    return;
-  }
+  GtkFontDialog * dialog;
+  struct FontSettingDialog *d;
 
   d = (struct FontSettingDialog *) client_data;
-  family = gtk_font_chooser_get_font_family(GTK_FONT_CHOOSER(dialog));
+  dialog = GTK_FONT_DIALOG (source_object);
+  family = gtk_font_dialog_choose_family_finish (dialog, res, NULL);
   if (family) {
     const gchar *font_name;
     GtkStringList *list;
     font_name = pango_font_family_get_name(family);
     list = listview_get_string_list (d->list);
     gtk_string_list_append (list, font_name);
+    g_object_unref (family);
   }
-  gtk_window_destroy(GTK_WINDOW(dialog));
 }
 
 static void
-FontSettingDialogAddAlternative(GtkWidget *w, gpointer client_data)
+FontSettingDialogAddAlternative(struct FontSettingDialog *d)
 {
-  struct FontSettingDialog *d;
-  GtkWidget *dialog;
+  GtkFontDialog *dialog;
 
-  d = (struct FontSettingDialog *) client_data;
-
-  dialog = gtk_font_chooser_dialog_new(_("Alternative font"), GTK_WINDOW(d->widget));
-  gtk_font_chooser_set_level(GTK_FONT_CHOOSER(dialog), GTK_FONT_CHOOSER_LEVEL_FAMILY);
-
-  g_signal_connect(dialog, "response", G_CALLBACK(FontSettingDialogAddAlternative_response), d);
-  gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
-  gtk_window_present(GTK_WINDOW (dialog));
+  dialog = gtk_font_dialog_new ();
+  gtk_font_dialog_set_title (dialog, _("Alternative font"));
+  gtk_font_dialog_set_modal (dialog, TRUE);
+  gtk_font_dialog_choose_family (dialog, GTK_WINDOW(d->widget), NULL, NULL, FontSettingDialogAddAlternative_response, d);
+  g_object_unref (dialog);
 }
 
 static void
-FontSettingDialogRemoveAlternative(GtkWidget *w, gpointer client_data)
+FontSettingDialogRemoveAlternative(struct FontSettingDialog *d)
 {
-  struct FontSettingDialog *d;
   int sel;
   GtkStringList *list;
   GtkSelectionModel *model;
 
-  d = (struct FontSettingDialog *) client_data;
-
   sel = listview_get_active(d->list);
   if (sel < 0) {
     return;
@@ -632,15 +627,12 @@ FontSettingDialogRemoveAlternative(GtkWidget *w, gpointer client_data)
 }
 
 static void
-FontSettingDialogDownAlternative(GtkWidget *wi, gpointer data)
+FontSettingDialogDownAlternative(struct FontSettingDialog *d)
 {
-  struct FontSettingDialog *d;
   GtkSelectionModel *model;
   GtkStringList *list;
   int n, sel;
 
-  d = (struct FontSettingDialog *) data;
-
   sel = listview_get_active(d->list);
   if (sel < 0) {
     return;
@@ -656,19 +648,16 @@ FontSettingDialogDownAlternative(GtkWidget *wi, gpointer data)
   }
 
   gtk_selection_model_select_item (model, sel, TRUE);
-  AlternativeFontListSelCb(model, 0, 0, data);
+  AlternativeFontListSelCb(model, 0, 0, d);
 }
 
 static void
-FontSettingDialogUpAlternative(GtkWidget *wi, gpointer data)
+FontSettingDialogUpAlternative(struct FontSettingDialog *d)
 {
-  struct FontSettingDialog *d;
   GtkStringList *list;
   GtkSelectionModel *model;
   int sel;
 
-  d = (struct FontSettingDialog *) data;
-
   sel = listview_get_active(d->list);
   if (sel < 1) {
     return;
@@ -679,13 +668,14 @@ FontSettingDialogUpAlternative(GtkWidget *wi, gpointer data)
 
   model = gtk_list_view_get_model(GTK_LIST_VIEW(d->list));
   gtk_selection_model_select_item (model, sel - 1, TRUE);
-  AlternativeFontListSelCb(model, 0, 0, data);
+  AlternativeFontListSelCb(model, 0, 0, d);
 }
 
 static void
 FontSettingDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
   struct FontSettingDialog *d;
+  (void) wi;
 
   d = (struct FontSettingDialog *) data;
 
@@ -701,9 +691,9 @@ FontSettingDialogSetup(GtkWidget *wi, void *data, int makewidget)
     add_widget_to_table(table, w, _("_Alias:"), TRUE, j++);
     d->alias = w;
 
-    w = gtk_font_button_new();
-    gtk_font_button_set_use_size(GTK_FONT_BUTTON(w), FALSE);
-    gtk_font_chooser_set_level(GTK_FONT_CHOOSER(w), GTK_FONT_CHOOSER_LEVEL_FAMILY);
+    w = gtk_font_dialog_button_new (gtk_font_dialog_new ());
+    gtk_font_dialog_button_set_use_size(GTK_FONT_DIALOG_BUTTON(w), FALSE);
+    gtk_font_dialog_button_set_level(GTK_FONT_DIALOG_BUTTON(w), GTK_FONT_LEVEL_FAMILY);
     add_widget_to_table(table, w, _("_Font:"), TRUE, j++);
     d->font_b = w;
 
@@ -728,23 +718,23 @@ FontSettingDialogSetup(GtkWidget *wi, void *data, int makewidget)
     vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 
     w= gtk_button_new_with_mnemonic(_("_Add"));
-    g_signal_connect(w, "clicked", G_CALLBACK(FontSettingDialogAddAlternative), d);
+    g_signal_connect_swapped(w, "clicked", G_CALLBACK(FontSettingDialogAddAlternative), d);
     gtk_box_append(GTK_BOX(vbox), w);
 
     w = gtk_button_new_with_mnemonic(_("_Remove"));
-    g_signal_connect(w, "clicked", G_CALLBACK(FontSettingDialogRemoveAlternative), d);
+    g_signal_connect_swapped(w, "clicked", G_CALLBACK(FontSettingDialogRemoveAlternative), d);
     gtk_box_append(GTK_BOX(vbox), w);
     gtk_widget_set_sensitive(w, FALSE);
     d->del_b = w;
 
     w = gtk_button_new_with_mnemonic(_("_Down"));
-    g_signal_connect(w, "clicked", G_CALLBACK(FontSettingDialogDownAlternative), d);
+    g_signal_connect_swapped(w, "clicked", G_CALLBACK(FontSettingDialogDownAlternative), d);
     gtk_box_append(GTK_BOX(vbox), w);
     gtk_widget_set_sensitive(w, FALSE);
     d->down_b = w;
 
     w = gtk_button_new_with_mnemonic(_("_Up"));
-    g_signal_connect(w, "clicked", G_CALLBACK(FontSettingDialogUpAlternative), d);
+    g_signal_connect_swapped(w, "clicked", G_CALLBACK(FontSettingDialogUpAlternative), d);
     gtk_box_append(GTK_BOX(vbox), w);
     gtk_widget_set_sensitive(w, FALSE);
     d->up_b = w;
@@ -756,7 +746,7 @@ FontSettingDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_append(GTK_BOX(d->vbox), frame);
   }
 
-  FontSettingDialogSetupItem(wi, d);
+  FontSettingDialogSetupItem(d);
 }
 
 static char *
@@ -790,13 +780,15 @@ static void
 FontSettingDialogClose(GtkWidget *wi, void *data)
 {
   struct FontSettingDialog *d;
-  gchar *alias, *family;
+  gchar *alias;
+  const gchar *family;
   const char *font;
-  gchar *font_name;
+  PangoFontDescription * desc;
   const struct fontmap *fmap;
   GString *alt;
   GtkStringList *list;
   int i, n;
+  (void) wi;
 
   d = (struct FontSettingDialog *) data;
 
@@ -821,13 +813,12 @@ FontSettingDialogClose(GtkWidget *wi, void *data)
     return;
   }
 
-  font_name = gtk_font_chooser_get_font(GTK_FONT_CHOOSER(d->font_b));
-  if (font_name == NULL) {
+  desc = gtk_font_dialog_button_get_font_desc (GTK_FONT_DIALOG_BUTTON (d->font_b));
+  if (desc == NULL) {
     g_free(alias);
     return;
   }
-  family = get_font_family(font_name);
-  g_free(font_name);
+  family = pango_font_description_get_family (desc);
   if (family == NULL) {
     g_free(alias);
     return;
@@ -838,7 +829,6 @@ FontSettingDialogClose(GtkWidget *wi, void *data)
   } else {
     gra2cairo_add_fontmap(alias, family);
   }
-  g_free(family);
 
   list = listview_get_string_list(d->list);
   n = g_list_model_get_n_items (G_LIST_MODEL (list));
@@ -908,6 +898,7 @@ PrefFontDialogUpdate(GtkWidget *w, gpointer client_data)
   const struct fontmap *fcur;
   NText *text;
   const char *fontalias;
+  (void) w;
 
   d = (struct PrefFontDialog *) client_data;
 
@@ -932,6 +923,7 @@ PrefFontDialogRemove(GtkWidget *w, gpointer client_data)
   struct PrefFontDialog *d;
   NText *text;
   const char *fontalias;
+  (void) w;
 
   d = (struct PrefFontDialog *) client_data;
 
@@ -948,6 +940,7 @@ static void
 PrefFontDialogAdd(GtkWidget *w, gpointer client_data)
 {
   struct PrefFontDialog *d;
+  (void) w;
 
   d = (struct PrefFontDialog *) client_data;
 
@@ -991,6 +984,7 @@ static void
 PrefFontDialogClose(GtkWidget *w, void *data)
 {
   const struct PrefFontDialog *d;
+  (void) w;
 
   d = (struct PrefFontDialog *) data;
 
@@ -1008,7 +1002,7 @@ PrefFontDialog(struct PrefFontDialog *data)
 }
 
 static void
-MiscDialogSetupItem(GtkWidget *w, struct MiscDialog *d)
+MiscDialogSetupItem(struct MiscDialog *d)
 {
   if (Menulocal.editor) {
     editable_set_init_text(d->editor, Menulocal.editor);
@@ -1035,15 +1029,15 @@ MiscDialogSetupItem(GtkWidget *w, struct MiscDialog *d)
   spin_entry_set_val(d->data_head_lines, Menulocal.data_head_lines);
 
   if (Menulocal.coordwin_font) {
-    gtk_font_chooser_set_font(GTK_FONT_CHOOSER(d->coordwin_font), Menulocal.coordwin_font);
+    font_button_set_font(d->coordwin_font, Menulocal.coordwin_font);
   }
 
   if (Menulocal.infowin_font) {
-    gtk_font_chooser_set_font(GTK_FONT_CHOOSER(d->infowin_font), Menulocal.infowin_font);
+    font_button_set_font(d->infowin_font, Menulocal.infowin_font);
   }
 
   if (Menulocal.file_preview_font) {
-    gtk_font_chooser_set_font(GTK_FONT_CHOOSER(d->file_preview_font), Menulocal.file_preview_font);
+    font_button_set_font(d->file_preview_font, Menulocal.file_preview_font);
   }
 
   gtk_check_button_set_active(GTK_CHECK_BUTTON(d->select_data), Menulocal.select_data);
@@ -1076,6 +1070,7 @@ static void
 set_file_in_entry(GtkEntry *w, GtkEntryIconPosition icon_pos, gpointer user_data)
 {
   struct MiscDialog *d;
+  (void) icon_pos;
 
   d = (struct MiscDialog *) user_data;
   nGetOpenFileName(d->widget, _("Select program"), NULL, NULL, NULL, FALSE,
@@ -1154,11 +1149,10 @@ edit_custom_palette_dialog_response(GtkDialog* self, gint response_id, gpointer
 }
 
 static void
-edit_custom_palette(GtkWidget *w, gpointer data)
+edit_custom_palette(struct MiscDialog *d)
 {
   GtkWidget *dialog, *box, **btns;
-  struct MiscDialog *d;
-  d = data;
+
   dialog = gtk_dialog_new_with_buttons(_("custom palette"),
 				       GTK_WINDOW(d->widget),
 #if USE_HEADER_BAR
@@ -1187,6 +1181,7 @@ static void
 MiscDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
   struct MiscDialog *d;
+  (void) wi;
 
   d = (struct MiscDialog *) data;
   if (makewidget) {
@@ -1288,15 +1283,15 @@ MiscDialogSetup(GtkWidget *wi, void *data, int makewidget)
     table = gtk_grid_new();
 
     i = 0;
-    w = gtk_font_button_new();
+    w = gtk_font_dialog_button_new (gtk_font_dialog_new ());
     add_widget_to_table(table, w, _("_Coordinate view:"), FALSE, i++);
     d->coordwin_font = w;
 
-    w = gtk_font_button_new();
+    w = gtk_font_dialog_button_new (gtk_font_dialog_new ());
     add_widget_to_table(table, w, _("_Information view:"), FALSE, i++);
     d->infowin_font = w;
 
-    w = gtk_font_button_new();
+    w = gtk_font_dialog_button_new (gtk_font_dialog_new ());
     add_widget_to_table(table, w, _("data _Preview:"), FALSE, i++);
     d->file_preview_font = w;
 
@@ -1320,7 +1315,7 @@ MiscDialogSetup(GtkWidget *wi, void *data, int makewidget)
     d->use_custom_palette = w;
 
     w = gtk_button_new_with_mnemonic(_("_Edit custom palette"));
-    g_signal_connect(w, "clicked", G_CALLBACK(edit_custom_palette), d);
+    g_signal_connect_swapped(w, "clicked", G_CALLBACK(edit_custom_palette), d);
     add_widget_to_table(table, w, NULL, FALSE, i++);
 
     w = gtk_source_style_scheme_chooser_button_new();
@@ -1347,15 +1342,20 @@ MiscDialogSetup(GtkWidget *wi, void *data, int makewidget)
     gtk_box_append(GTK_BOX(hbox2), vbox2);
     gtk_box_append(GTK_BOX(d->vbox), hbox2);
   }
-  MiscDialogSetupItem(wi, d);
+  MiscDialogSetupItem(d);
 }
 
 static int
 set_font(char **cfg, GtkWidget *btn)
 {
   char *buf;
+  PangoFontDescription *desc;
 
-  buf = gtk_font_chooser_get_font(GTK_FONT_CHOOSER(btn));
+  desc = gtk_font_dialog_button_get_font_desc (GTK_FONT_DIALOG_BUTTON (btn));
+  if (desc == NULL) {
+    return 0;
+  }
+  buf = pango_font_description_to_string (desc);
   if (buf && *cfg) {
     if (strcmp(*cfg, buf)) {
       g_free(*cfg);
@@ -1401,6 +1401,7 @@ MiscDialogClose(GtkWidget *w, void *data)
   const char *buf, *source_style_id;
   char *buf2;
   GtkSourceStyleScheme *source_style;
+  (void) w;
 
   d = (struct MiscDialog *) data;
 
@@ -1504,7 +1505,7 @@ MiscDialog(struct MiscDialog *data, struct objlist *obj, int id)
 }
 
 static void
-ExViewerDialogSetupItem(GtkWidget *w, struct ExViewerDialog *d)
+ExViewerDialogSetupItem(struct ExViewerDialog *d)
 {
   gtk_check_button_set_active(GTK_CHECK_BUTTON(d->use_external), Menulocal.exwin_use_external);
   gtk_range_set_value(GTK_RANGE(d->dpi), Menulocal.exwindpi);
@@ -1532,6 +1533,7 @@ static void
 ExViewerDialogSetup(GtkWidget *wi, void *data, int makewidget)
 {
   struct ExViewerDialog *d;
+  (void) wi;
 
   d = (struct ExViewerDialog *) data;
   if (makewidget) {
@@ -1562,13 +1564,14 @@ ExViewerDialogSetup(GtkWidget *wi, void *data, int makewidget)
 
     gtk_box_append(GTK_BOX(d->vbox), table);
   }
-  ExViewerDialogSetupItem(wi, d);
+  ExViewerDialogSetupItem(d);
 }
 
 static void
 ExViewerDialogClose(GtkWidget *w, void *data)
 {
   struct ExViewerDialog *d;
+  (void) w;
 
   d = (struct ExViewerDialog *) data;
 
@@ -1598,6 +1601,7 @@ ViewerDialogSetupItem(GtkWidget *w, struct ViewerDialog *d)
 {
   int a;
   GdkRGBA color;
+  (void) w;
 
   getobj(d->Obj, "dpi", d->Id, 0, NULL, &(d->dpis));
   gtk_range_set_value(GTK_RANGE(d->dpi), d->dpis);
@@ -1659,7 +1663,7 @@ ViewerDialogSetup(GtkWidget *wi, void *data, int makewidget)
     add_widget_to_table(table, w, _("_Grid:"), FALSE, i++);
     d->grid = w;
 
-    w = create_color_button(wi);
+    w = create_color_button();
     add_widget_to_table(table, w, _("_Background Color:"), FALSE, i++);
     d->bgcol = w;
 
@@ -1700,6 +1704,7 @@ ViewerDialogClose(GtkWidget *w, void *data)
   struct ViewerDialog *d;
   int ret, dpi, a, bg;
   GdkRGBA color;
+  (void) w;
 
   d = (struct ViewerDialog *) data;
 
@@ -1777,6 +1782,7 @@ ViewerDialog(struct ViewerDialog *data, struct objlist *obj, int id)
 static void
 save_default_axis_config_response(int ret, struct objlist *obj, int id, int modified)
 {
+  (void) modified;
   if (ret) {
     exeobj(obj, "save_config", id, 0, NULL);
   }
