@@ -65,17 +65,20 @@ void SetScroller(void);
 void Focus(struct objlist *fobj, int id, enum FOCUS_MODE mode);
 void UnFocus(void);
 void ChangeDPI(void);
-void Draw(int SelectFile);
 void CmViewerClear(void *w, gpointer client_data);
-void CmViewerDraw(void *w, gpointer client_data);
-gboolean CmViewerButtonPressed(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
-int data_dropped(char **filenames, int num, int file_type);
+void CmViewerDraw(int select_file);
+typedef void (* draw_cb) (gpointer);
+void Draw(int SelectFile, draw_cb cb, gpointer user_data);
+void CmViewerButtonPressed(GtkGestureClick *gesture, gint n_press, gdouble x, gdouble y, gpointer user_data);
+int data_dropped(struct narray *filenames, int file_type);
+struct narray *get_dropped_files(const GValue* value);
 void draw_paper_frame(void);
-void CmEditMenuCB(void *w, gpointer client_data);
+void CmEditMenuCB(int menu_id);
 void ViewCross(int state);
-void ViewerUpdateCB(void *w, gpointer client_data);
+void ViewerUpdateCB(void);
 int check_focused_obj_type(const struct Viewer *d, int *type);
 void move_data_cancel(struct Viewer *d, gboolean show_message);
 int check_paint_lock(void);
 void update_bg(void);
 int get_focused_obj_array(struct narray *focusobj, char **objs);
+int graph_dropped(const char *fname);
