@@ -473,7 +473,7 @@ nsearchpath(char *path,char *name,int shellscript)
   }
 
   if (strchr(name,DIRSEP)==NULL) {
-    char *tok;
+    const char *tok;
     while ((tok=getitok(&path,&len,PATHSEP))!=NULL) {
       g_free(cmdname);
       if ((cmdname=g_malloc(strlen(name)+len+2))==NULL) return NULL;
@@ -501,7 +501,7 @@ nsearchpath(char *path,char *name,int shellscript)
 }
 
 static int
-nscandir(char *dir,char ***namelist, int (*compar)())
+nscandir(char *dir,char ***namelist, int (*compar)(const void *, const void *))
 {
   unsigned int i;
   GDir *dp;
@@ -556,13 +556,14 @@ nscandir(char *dir,char ***namelist, int (*compar)())
 }
 
 static int
-nalphasort(char **a,char **b)
+nalphasort(const void *pa, const void *pb)
 {
+  char * const *a = pa, * const *b = pb;
   return strcmp(*a,*b);
 }
 
 static int
-nglob2(char *path,int po,int *num,char ***list)
+nglob2(const char *path,int po,int *num,char ***list)
 {
   int i,j,p1,escape;
   char **namelist, *s;
