@@ -314,11 +314,10 @@ static char OpeChar[256] = {
   0,
   0,
 };
-
 int
 math_scanner_is_ope(int chr)
 {
-  if (chr < 0 || chr > (int) (sizeof(OpeChar) / sizeof(*OpeChar)))
+  if (chr < 0 || chr >= (int) (sizeof(OpeChar) / sizeof(*OpeChar)))
     return 0;
 
   return OpeChar[chr];
