@@ -4,6 +4,15 @@
 enum MATH_OPERATOR_TYPE {
   MATH_OPERATOR_TYPE_AND,
   MATH_OPERATOR_TYPE_ASSIGN,
+  MATH_OPERATOR_TYPE_BIT_AND,
+  MATH_OPERATOR_TYPE_BIT_AND_ASSIGN,
+  MATH_OPERATOR_TYPE_BIT_NOT,
+  MATH_OPERATOR_TYPE_BIT_OR,
+  MATH_OPERATOR_TYPE_BIT_OR_ASSIGN,
+  MATH_OPERATOR_TYPE_BIT_SHIFT_L,
+  MATH_OPERATOR_TYPE_BIT_SHIFT_L_ASSIGN,
+  MATH_OPERATOR_TYPE_BIT_SHIFT_R,
+  MATH_OPERATOR_TYPE_BIT_SHIFT_R_ASSIGN,
   MATH_OPERATOR_TYPE_DIV,
   MATH_OPERATOR_TYPE_DIV_ASSIGN,
   MATH_OPERATOR_TYPE_EOEQ,
