@@ -5,6 +5,9 @@
 
 #ifndef MATH_SCANNER_HEADER
 #define MATH_SCANNER_HEADER
+#include <gmodule.h>
+
+#define MATH_VARIABLE_EXPAND_PREFIX 0x01
 
 struct math_string {
   const char *top, *cur;
@@ -17,6 +20,10 @@ struct math_string {
 enum MATH_TOKEN_TYPE {
   MATH_TOKEN_TYPE_NUMERIC,
   MATH_TOKEN_TYPE_SYMBOL,
+  MATH_TOKEN_TYPE_DOUBLE_QUOTED_STRING,
+  MATH_TOKEN_TYPE_SINGLE_QUOTED_STRING,
+  MATH_TOKEN_TYPE_UNTERMINATED_STRING,
+  MATH_TOKEN_TYPE_STRING_VARIABLE,
   MATH_TOKEN_TYPE_OPERATOR,
   MATH_TOKEN_TYPE_LP,
   MATH_TOKEN_TYPE_RP,
@@ -29,6 +36,7 @@ enum MATH_TOKEN_TYPE {
   MATH_TOKEN_TYPE_COMMA,
   MATH_TOKEN_TYPE_ARRAY_PREFIX,
   MATH_TOKEN_TYPE_EOEQ,
+  MATH_TOKEN_TYPE_EOEQ_ASSIGN,
   MATH_TOKEN_TYPE_UNKNOWN,
 };
 
@@ -41,13 +49,16 @@ struct math_token {
     } val;
     enum MATH_OPERATOR_TYPE op;
     char *sym;
+    GString *str;
   } data;
   const char *ptr;
   struct math_token *next;
 };
 
-struct math_token *math_scanner_get_token(struct math_string *rstr);
+struct math_token *math_scanner_get_token(struct math_string *rstr, MathEquation *eq);
+struct math_token *math_scanner_dup_token(struct math_token *token);
 void math_scanner_free_token(struct math_token *token);
 void math_scanner_init_string(struct math_string *str, const char *line);
+void replace_eoeq_token(char *eq);
 
 #endif
