@@ -228,7 +228,8 @@ get_grid_prm(struct objlist *obj, char *axisy,
 	if (anum > 0) {
 	  id = arraylast_int(&iarray);
 	  arraydel(&iarray);
-	  if (anum > 0 && (inst1 = getobjinst(aobj, id))) {
+	  inst1 = getobjinst(aobj, id);
+	  if (inst1) {
 	    _getobj(aobj, "min", inst1, &prm->amin);
 	    _getobj(aobj, "max", inst1, &prm->amax);
 	    _getobj(aobj, "inc", inst1, &prm->inc);
@@ -269,8 +270,8 @@ get_grid_prm(struct objlist *obj, char *axisy,
 
 static int
 draw_grid_line(struct objlist *obj, int GC,
-	       struct axis_prm *a1_prm, struct axis_pos *a1_pos,
-	       struct axis_pos *a2_pos, struct grid_prm *gprm)
+	       struct axis_prm *a1_prm, const struct axis_pos *a1_pos,
+	       const struct axis_pos *a2_pos, struct grid_prm *gprm)
 {
   int r, rcode, snum, wid, *sdata;
   double po;
@@ -318,7 +319,7 @@ draw_grid_line(struct objlist *obj, int GC,
 }
 
 static int
-draw_background(struct objlist *obj, N_VALUE *inst, int GC, struct axis_pos *ax, struct axis_pos *ay)
+draw_background(struct objlist *obj, N_VALUE *inst, int GC, const struct axis_pos *ax, const struct axis_pos *ay)
 {
   int r, br, bg, bb, ba, pos[8];
 
