@@ -33,7 +33,9 @@
 #include "object.h"
 #include "ioutil.h"
 #include "ogra.h"
+#include "ogra_error.h"
 #include "gra.h"
+#include "nstring.h"
 
 #define NAME "gra"
 #define PARENT "object"
@@ -51,24 +53,40 @@ static char *GRAerrorlist[]={
 
 #define ERRNUM (sizeof(GRAerrorlist) / sizeof(*GRAerrorlist))
 
+char *gra_decimalsign_char[]={
+  N_("period"),
+  N_("comma"),
+  NULL
+};
+
+static enum GRA_DECIMALSIGN_TYPE DefaultDecimalsign = GRA_DECIMALSIGN_TYPE_PERIOD;
+
 static void set_progress_val(int i, int n, const char *name);
 static int oGRAclose(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv);
 
+void
+gra_set_default_decimalsign(enum GRA_DECIMALSIGN_TYPE decimalsign)
+{
+  DefaultDecimalsign = decimalsign;
+}
+
 static int
 oGRAinit(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
-  int GC,width,height,zoom;
+  int GC,width,height,zoom, decimalsign;
 
   if (_exeparent(obj,(char *)argv[1],inst,rval,argc,argv)) return 1;
   GC=-1;
   width=21000;
   height=29700;
   zoom=10000;
+  decimalsign = DefaultDecimalsign;
   if (_putobj(obj,"open",inst,&GC)) return 1;
   if (_putobj(obj,"GC",inst,&GC)) return 1;
   if (_putobj(obj,"zoom",inst,&zoom)) return 1;
   if (_putobj(obj,"paper_width",inst,&width)) return 1;
   if (_putobj(obj,"paper_height",inst,&height)) return 1;
+  if (_putobj(obj, "decimalsign", inst, &decimalsign)) return 1;
   return 0;
 }
 
@@ -91,7 +109,7 @@ oGRAdisconnect(struct objlist *obj,void *inst,int clear)
       && ((dinst=chkobjinstoid(dobj,did))!=NULL)) {
     if ((!chkobjfield(dobj,"_list"))
         && (!_getobj(dobj,"_list",dinst,&sarray)) && (sarray!=NULL)) {
-      struct objlist *gobj;
+      const struct objlist *gobj;
       char *list;
       list=arraynget_str(sarray,0);
       if (((gobj=getobjlist(list,&gid,&gfield,NULL))!=NULL)
@@ -260,10 +278,11 @@ oGRAopen(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 
     if (oGRAdisconnect(obj,inst,FALSE)) return 1;
     if (!_getobj(dobj,"oid",dinst,&oid)) {
-      if ((dev=mkobjlist(dobj,NULL,oid,"_output",TRUE))!=NULL)
-      if (_putobj(obj,"_device",inst,dev)) {
-        g_free(dev);
-        return 1;
+      if ((dev=mkobjlist(dobj,NULL,oid,"_output",TRUE))!=NULL) {
+	if (_putobj(obj,"_device",inst,dev)) {
+	  g_free(dev);
+	  return 1;
+	}
       }
     }
   }
@@ -290,6 +309,22 @@ oGRAclose(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   return close_gc(obj, inst, GC);
 }
 
+static void
+set_gra_decimalsign(struct objlist *obj, N_VALUE *inst)
+{
+  enum GRA_DECIMALSIGN_TYPE decimalsign;
+
+  _getobj(obj, "decimalsign", inst, &decimalsign);
+  switch (decimalsign) {
+  case GRA_DECIMALSIGN_TYPE_PERIOD:
+    set_decimalsign(DECIMALSIGN_TYPE_PERIOD);
+    break;
+  case GRA_DECIMALSIGN_TYPE_COMMA:
+    set_decimalsign(DECIMALSIGN_TYPE_COMMA);
+    break;
+  }
+}
+
 static int
 oGRAredraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
@@ -304,6 +339,7 @@ oGRAredraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   if (device == NULL) {
     return 0;
   }
+  set_gra_decimalsign(obj, inst);
   if (((dobj=getobjlist(device,&did,&dfield,NULL))!=NULL)
       && ((dinst=chkobjinstoid(dobj,did))!=NULL)) {
     if (chkobjfield(dobj,field)==0) _exeobj(dobj,field,dinst,0,NULL);
@@ -339,7 +375,7 @@ static int
 oGRAputtopm(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
   int GC;
-  char *arg;
+  const char *arg;
 
   _getobj(obj,"GC",inst,&GC);
   if (GC!=-1) {
@@ -357,7 +393,7 @@ oGRAputtopm(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv
 }
 
 static int
-oGRAdrawparent(struct objlist *parent, char **oGRAargv, int layer)
+oGRAdrawparent(const struct objlist *parent, char **oGRAargv, int layer)
 {
   struct objlist *ocur;
   int i,instnum;
@@ -400,6 +436,7 @@ oGRAdraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
     return 1;
   }
 
+  set_gra_decimalsign(obj, inst);
   layer = GRAlayer_support(GC);
   _getobj(obj,"draw_obj",inst,&array);
   oGRAargv[0]=(char *)&GC;
@@ -464,6 +501,7 @@ static struct objtable GRA[] = {
   {"zoom",NINT,NREAD|NWRITE,oGRAputtopm,NULL,0},
   {"paper_width",NINT,NREAD|NWRITE,oGRAputtopm,NULL,0},
   {"paper_height",NINT,NREAD|NWRITE,oGRAputtopm,NULL,0},
+  {"decimalsign",NENUM,NREAD|NWRITE,NULL,gra_decimalsign_char,0},
   {"draw_obj",NSARRAY,NREAD|NWRITE,NULL,NULL,0},
   {"GC",NINT,NREAD,NULL,NULL,0},
   {"redraw",NVFUNC,NREAD|NEXEC,oGRAredraw,"",0},
