@@ -132,7 +132,6 @@ rectdraw(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
     GRArectangle(GC,x1,y1,x2,y2,0);
   }
 
-  GRAaddlist(GC,obj,inst,(char *)argv[0],(char *)argv[1]);
   return 0;
 }
 
@@ -340,7 +339,7 @@ rectchange(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 static int
 rectzoom(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
 {
-  int i,snum,*sdata,refx,refy,x1,y1,x2,y2,width,preserve_width;
+  int snum,*sdata,refx,refy,x1,y1,x2,y2,width,preserve_width;
   double zoom_x, zoom_y;
   struct narray *style;
 
@@ -363,6 +362,7 @@ rectzoom(struct objlist *obj,N_VALUE *inst,N_VALUE *rval,int argc,char **argv)
   x2=(x2-refx)*zoom_x+refx;
   y2=(y2-refy)*zoom_y+refy;
   if (! preserve_width) {
+    int i;
     double zoom;
     zoom = MIN(zoom_x, zoom_y);
     width = width * zoom;
